# SSNP

Split-step non-paraxial beam propagation method

## Features

* Forward model calculation based on CUDA
* Read/write data of common file type
* Gradient calculation
* Image reconstruction with regularization

## Reference

Sharma, A., & Agrawal, A. (2004). Split-step non-paraxial beam propagation method. *Physics and Simulation of Optoelectronic Devices XII*, 5349, 132. https://doi.org/10.1117/12.528172

Lim, J., Ayoub, A. B., Antoine, E. E., & Psaltis, D. (2019). High-fidelity optical diffraction tomography of multiple scattering samples. *Light: Science & Applications*, 8(1), 82. https://doi.org/10.1038/s41377-019-0195-1
